ndn-hydra: an NDN distributed repo
==================================

A Named Data Networking (NDN) Distributed Repo implementation using python-ndn_.

Hydra uses StateVectorSync_ (SVS) to communicate in a distributed environment.

Please see our documentation_.

.. _python-ndn: https://github.com/named-data/python-ndn

.. _StateVectorSync: https://github.com/justincpresley/ndn-python-svs

.. _documentation: https://ndn-hydra.readthedocs.io/en/latest